@@ -12,9 +12,11 @@ class SwitchbotModel(StrEnum):
 
     BOT = "WoHand"
     CURTAIN = "WoCurtain"
+    HUMIDIFIER = "WoHumi"
     PLUG_MINI = "WoPlug"
     CONTACT_SENSOR = "WoContact"
     LIGHT_STRIP = "WoStrip"
     METER = "WoSensorTH"
     MOTION_SENSOR = "WoPresence"
     COLOR_BULB = "WoBulb"
+    CEILING_LIGHT = "WoCeiling"
